package com.tzld.longarticle.recommend.server.service.filter.strategy;

import com.google.common.collect.Sets;
import com.tzld.longarticle.recommend.server.model.Content;
import com.tzld.longarticle.recommend.server.repository.ArticlePreDistributeAccount;
import com.tzld.longarticle.recommend.server.repository.ArticlePreDistributeAccountRepository;
import com.tzld.longarticle.recommend.server.service.AccountContentPoolConfigService;
import com.tzld.longarticle.recommend.server.service.filter.FilterParam;
import com.tzld.longarticle.recommend.server.service.filter.FilterResult;
import com.tzld.longarticle.recommend.server.service.filter.FilterStrategy;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;
import java.util.Set;

/**
 * @author dyp
 */
@Component
@Slf4j
public class AccountPreDistributeStrategy implements FilterStrategy {
    @Autowired
    private AccountContentPoolConfigService accountContentPoolConfigService;
    @Autowired
    private ArticlePreDistributeAccountRepository articlePreDistributeAccountRepository;

    @Override
    public FilterResult filter(FilterParam param) {
        FilterResult filterResult = new FilterResult();
        List<String> result = new ArrayList<>();
        List<Content> contents = param.getContents();
        List<Content> filterContents = new ArrayList<>();
        String[] pools = accountContentPoolConfigService.getContentPools(param.getAccountName());
        if (pools.length >= 3) {
            ArticlePreDistributeAccount articlePreDistributeAccount =
                    articlePreDistributeAccountRepository.findByGhIdOrderByDate(param.getAccountId());
            if (StringUtils.isNotEmpty(articlePreDistributeAccount.getArticleList())) {
                Set<String> articles = Sets.newHashSet(StringUtils.split(","));
                for (Content content : contents) {
                    if (StringUtils.equals(pools[2], content.getContentPoolType())) {
                        if (articles.contains(content.getId())) {
                            result.add(content.getId());
                        }
                    }
                }
            }
        }
        filterResult.setContentIds(result);
        filterResult.setFilterContent(filterContents);
        return filterResult;
    }

}
